@@ -2,14 +2,11 @@
 # this repository contains the full copyright notices and license terms.
 import datetime
 
-from trytond.pool import PoolMeta, Pool
 from trytond.model import fields
+from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 
 
-__all__ = ['Location', 'LocationLeadTime']
-
-
 class Location(metaclass=PoolMeta):
     __name__ = 'stock.location'
 
@@ -17,24 +14,20 @@ class Location(metaclass=PoolMeta):
         'Provisioning Location',
         states={
             'invisible': Eval('type') != 'storage',
-            'readonly': ~Eval('active'),
             },
         domain=[
             ('type', 'in', ['storage', 'view']),
             ],
-        depends=['type', 'active'],
-        help='Leave empty for no default provisioning')
+        help='Leave empty for no default provisioning.')
     overflowing_location = fields.Many2One('stock.location',
         'Overflowing Location',
         states={
             'invisible': Eval('type') != 'storage',
-            'readonly': ~Eval('active'),
             },
         domain=[
             ('type', 'in', ['storage', 'view']),
             ],
-        depends=['type', 'active'],
-        help='Leave empty for no default overflowing')
+        help='Leave empty for no default overflowing.')
 
 
 class LocationLeadTime(metaclass=PoolMeta):
