@@ -1,11 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from sql import Null
-
 from trytond.i18n import gettext
-from trytond.model import ModelView, ModelSQL, fields
+from trytond.model import ModelSQL, ModelView, fields
 from trytond.pool import Pool
-from trytond.pyson import If, Equal, Eval, Not, In
+from trytond.pyson import Equal, Eval, If, In, Not
 from trytond.transaction import Transaction
 
 from .exceptions import OrderPointValidationError
@@ -19,8 +17,8 @@ class OrderPoint(ModelSQL, ModelView):
     considered by the supply scheduler to generate purchase requests.
     """
     __name__ = 'stock.order_point'
-    product = fields.Many2One('product.product', 'Product', required=True,
-        select=True,
+    product = fields.Many2One(
+        'product.product', "Product", required=True,
         domain=[
             ('type', '=', 'goods'),
             ('consumable', '=', False),
@@ -30,23 +28,21 @@ class OrderPoint(ModelSQL, ModelView):
         context={
             'company': Eval('company', -1),
             },
-        depends=['type', 'company'])
-    warehouse_location = fields.Many2One('stock.location',
-        'Warehouse Location', select=True,
+        depends={'company'})
+    warehouse_location = fields.Many2One(
+        'stock.location', 'Warehouse Location',
         domain=[('type', '=', 'warehouse')],
         states={
             'invisible': Not(Equal(Eval('type'), 'purchase')),
             'required': Equal(Eval('type'), 'purchase'),
-            },
-        depends=['type'])
-    storage_location = fields.Many2One('stock.location', 'Storage Location',
-        select=True,
+            })
+    storage_location = fields.Many2One(
+        'stock.location', "Storage Location",
         domain=[('type', '=', 'storage')],
         states={
             'invisible': Not(Equal(Eval('type'), 'internal')),
             'required': Equal(Eval('type'), 'internal'),
-        },
-        depends=['type'])
+        })
     location = fields.Function(fields.Many2One('stock.location', 'Location'),
             'get_location', searcher='search_location')
     provisioning_location = fields.Many2One(
@@ -56,8 +52,7 @@ class OrderPoint(ModelSQL, ModelView):
             'invisible': Not(Equal(Eval('type'), 'internal')),
             'required': ((Eval('type') == 'internal')
                 & (Eval('min_quantity', None) != None)),  # noqa: E711
-        },
-        depends=['type', 'min_quantity'])
+        })
     overflowing_location = fields.Many2One(
         'stock.location', 'Overflowing Location',
         domain=[('type', 'in', ['storage', 'view'])],
@@ -65,14 +60,13 @@ class OrderPoint(ModelSQL, ModelView):
             'invisible': Eval('type') != 'internal',
             'required': ((Eval('type') == 'internal')
                 & (Eval('max_quantity', None) != None)),  # noqa: E711
-            },
-        depends=['type', 'max_quantity'])
+            })
     type = fields.Selection(
         [('internal', 'Internal'),
          ('purchase', 'Purchase')],
-        'Type', select=True, required=True)
-    min_quantity = fields.Float('Minimal Quantity',
-        digits=(16, Eval('unit_digits', 2)),
+        "Type", required=True)
+    min_quantity = fields.Float(
+        "Minimal Quantity", digits='unit',
         states={
             # required for purchase and production types
             'required': Eval('type') != 'internal',
@@ -80,10 +74,9 @@ class OrderPoint(ModelSQL, ModelView):
         domain=['OR',
             ('min_quantity', '=', None),
             ('min_quantity', '<=', Eval('target_quantity', 0)),
-            ],
-        depends=['unit_digits', 'target_quantity', 'type'])
-    target_quantity = fields.Float('Target Quantity', required=True,
-        digits=(16, Eval('unit_digits', 2)),
+            ])
+    target_quantity = fields.Float(
+        "Target Quantity", digits='unit', required=True,
         domain=[
             ['OR',
                 ('min_quantity', '=', None),
@@ -93,65 +86,40 @@ class OrderPoint(ModelSQL, ModelView):
                 ('max_quantity', '=', None),
                 ('target_quantity', '<=', Eval('max_quantity', 0)),
                 ],
-            ],
-        depends=['unit_digits', 'min_quantity', 'max_quantity'])
-    max_quantity = fields.Float('Maximal Quantity',
-        digits=(16, Eval('unit_digits', 2)),
+            ])
+    max_quantity = fields.Float(
+        "Maximal Quantity", digits='unit',
         states={
             'invisible': Eval('type') != 'internal',
             },
         domain=['OR',
             ('max_quantity', '=', None),
             ('max_quantity', '>=', Eval('target_quantity', 0)),
-            ],
-        depends=['unit_digits', 'type', 'target_quantity'])
+            ])
     company = fields.Many2One('company.company', 'Company', required=True,
             domain=[
                 ('id', If(In('company', Eval('context', {})), '=', '!='),
                     Eval('context', {}).get('company', -1)),
             ])
     unit = fields.Function(fields.Many2One('product.uom', 'Unit'), 'get_unit')
-    unit_digits = fields.Function(fields.Integer('Unit Digits'),
-            'get_unit_digits')
-
-    @classmethod
-    def __register__(cls, module_name):
-        cursor = Transaction().connection.cursor()
-        sql_table = cls.__table__()
-        table = cls.__table_handler__(module_name)
-
-        # Migration from 4.2
-        table.drop_constraint('check_max_qty_greater_min_qty')
-        table.not_null_action('min_quantity', 'remove')
-        table.not_null_action('max_quantity', 'remove')
-        target_qty_exist = table.column_exist('target_quantity')
-
-        super(OrderPoint, cls).__register__(module_name)
-
-        # Migration from 4.2
-        if not target_qty_exist:
-            cursor.execute(*sql_table.update(
-                    [sql_table.target_quantity, sql_table.max_quantity],
-                    [sql_table.max_quantity, Null]))
 
     @staticmethod
     def default_type():
         return "purchase"
 
+    @classmethod
+    def default_warehouse_location(cls):
+        return Pool().get('stock.location').get_default_warehouse()
+
     @fields.depends('product', '_parent_product.default_uom')
     def on_change_product(self):
         self.unit = None
-        self.unit_digits = 2
         if self.product:
             self.unit = self.product.default_uom
-            self.unit_digits = self.product.default_uom.digits
 
     def get_unit(self, name):
         return self.product.default_uom.id
 
-    def get_unit_digits(self, name):
-        return self.product.default_uom.digits
-
     @classmethod
     def validate(cls, orderpoints):
         super(OrderPoint, cls).validate(orderpoints)
@@ -165,10 +133,7 @@ class OrderPoint(ModelSQL, ModelView):
         points. I.E. no two order point with opposite location for the
         same product and same company.
         """
-        internals = cls.search([
-                ('id', 'in', [o.id for o in orders]),
-                ('type', '=', 'internal'),
-                ])
+        internals = cls.browse([o for o in orders if o.type == 'internal'])
         if not internals:
             return
 
