@@ -3,7 +3,7 @@
 import datetime
 
 from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 
 
 class Product(metaclass=PoolMeta):
