@@ -1,17 +1,19 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import datetime
+from collections import defaultdict
 
-from trytond.model import ModelView, ModelSQL
-from trytond.transaction import Transaction
+from trytond.model import ModelSQL, ModelView
 from trytond.pool import Pool
+from trytond.tools import grouped_slice
+from trytond.transaction import Transaction
 
 
 class ShipmentInternal(ModelSQL, ModelView):
     __name__ = 'stock.shipment.internal'
 
     @classmethod
-    def generate_internal_shipment(cls, clean=True):
+    def generate_internal_shipment(cls, clean=True, warehouses=None):
         """
         Generate internal shipments to meet order points defined on
         non-warehouse location.
@@ -30,6 +32,11 @@ class ShipmentInternal(ModelSQL, ModelView):
         if not company:
             return
 
+        if warehouses is None:
+            warehouses = Location.search([
+                    ('type', '=', 'warehouse'),
+                    ])
+
         today = Date.today()
         lead_time = LeadTime.get_max_lead_time()
 
@@ -42,9 +49,11 @@ class ShipmentInternal(ModelSQL, ModelView):
 
         # fetch quantities on order points
         order_points = OrderPoint.search([
-            ('type', '=', 'internal'),
-            ('company', '=', company.id),
-            ])
+                ('type', '=', 'internal'),
+                ('company', '=', company.id)
+                ])
+        order_points = [
+            op for op in order_points if op.location.warehouse in warehouses]
         id2product = {}
         product2op = {}
         id2location = {}
@@ -61,19 +70,26 @@ class ShipmentInternal(ModelSQL, ModelView):
         id2location.update({l.id: l for l in implicit_locations})
         location_ids = list(id2location.keys())
 
+        def get_pbl(start, end, grouping_filter):
+            with Transaction().set_context(
+                    forecast=True, stock_date_start=start, stock_date_end=end):
+                return Product.products_by_location(
+                    location_ids, with_childs=True,
+                    grouping_filter=grouping_filter)
+
         # ordered by ids to speedup reduce_ids in products_by_location
         if implicit_locations:
             products = Product.search([
                     ('type', 'in', ['goods', 'assets']),
                     ], order=[('id', 'ASC')])
             product_ids = [p.id for p in products]
+            pbl = get_pbl(None, today, None)
         else:
             product_ids = list(id2product.keys())
             product_ids.sort()
-
-        with Transaction().set_context(forecast=True, stock_date_end=today):
-            pbl = Product.products_by_location(
-                location_ids, with_childs=True, grouping_filter=(product_ids,))
+            pbl = defaultdict(int)
+            for sub_product_ids in grouped_slice(product_ids):
+                pbl.update(get_pbl(None, today, (list(sub_product_ids),)))
 
         shipments = []
         date = today
@@ -144,7 +160,7 @@ class ShipmentInternal(ModelSQL, ModelView):
                             planned_date=date,
                             product=product,
                             quantity=qty,
-                            uom=product.default_uom,
+                            unit=product.default_uom,
                             company=company,
                             ))
                 shipment.moves = shipment_moves
@@ -154,16 +170,14 @@ class ShipmentInternal(ModelSQL, ModelView):
             date += datetime.timedelta(1)
 
             # Update quantities with next moves
-            with Transaction().set_context(
-                    forecast=True,
-                    stock_date_start=date,
-                    stock_date_end=date):
-                pbl = Product.products_by_location(
-                    location_ids,
-                    with_childs=True,
-                    grouping_filter=(product_ids,))
-            for key, qty in pbl.items():
-                current_qties[key] += qty
+            if implicit_locations:
+                for key, qty in get_pbl(date, date, None).items():
+                    current_qties[key] += qty
+            else:
+                for sub_product_ids in grouped_slice(product_ids):
+                    for key, qty in get_pbl(
+                            date, date, (list(sub_product_ids),)).items():
+                        current_qties[key] += qty
 
         if shipments:
             cls.save(shipments)
