@@ -1,11 +1,11 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.i18n import gettext
+from trytond.model import ModelView, fields
 from trytond.pool import Pool
-from trytond.model import ModelView
-from trytond.transaction import Transaction
-from trytond.wizard import (Wizard, StateView, StateAction, StateTransition,
-    Button)
+from trytond.transaction import check_access
+from trytond.wizard import (
+    Button, StateAction, StateTransition, StateView, Wizard)
 
 from .exceptions import SupplyWarning
 
@@ -42,7 +42,7 @@ class Supply(Wizard):
         Date = pool.get('ir.date')
         Warning = pool.get('res.user.warning')
         today = Date.today()
-        with Transaction().set_context(_check_access=True):
+        with check_access():
             moves = Move.search([
                     ('from_location.type', '=', 'supplier'),
                     ('to_location.type', '=', 'storage'),
@@ -54,7 +54,7 @@ class Supply(Wizard):
             if Warning.check(name):
                 raise SupplyWarning(name,
                     gettext('stock_supply.msg_late_supplier_moves'))
-        with Transaction().set_context(_check_access=True):
+        with check_access():
             moves = Move.search([
                     ('from_location.type', '=', 'storage'),
                     ('to_location.type', '=', 'customer'),
@@ -76,7 +76,7 @@ class Supply(Wizard):
             first = False
 
         # Remove transit split of request
-        with Transaction().set_context(_check_access=True):
+        with check_access():
             shipments = ShipmentInternal.search([
                     ('state', '=', 'request'),
                     ])
@@ -94,14 +94,24 @@ class Supply(Wizard):
     def generate_internal(self, clean):
         pool = Pool()
         ShipmentInternal = pool.get('stock.shipment.internal')
-        return ShipmentInternal.generate_internal_shipment(clean=clean)
+        # Use getattr because start is empty when run by cron
+        if getattr(self.start, 'warehouses', None):
+            warehouses = self.start.warehouses
+        else:
+            warehouses = None
+        return ShipmentInternal.generate_internal_shipment(
+            clean=clean, warehouses=warehouses)
 
     def transition_internal(self):
         return self.next_action('internal')
 
     @property
     def _purchase_parameters(self):
-        return {}
+        parameters = {}
+        # Use getattr because start is empty when run by cron
+        if getattr(self.start, 'warehouses', None):
+            parameters['warehouses'] = self.start.warehouses
+        return parameters
 
     def generate_purchase(self, clean):
         pool = Pool()
@@ -116,3 +126,18 @@ class Supply(Wizard):
 class SupplyStart(ModelView):
     "Supply Stock"
     __name__ = 'stock.supply.start'
+
+    warehouses = fields.Many2Many(
+        'stock.location', None, None, "Warehouses",
+        domain=[
+            ('type', '=', 'warehouse'),
+            ],
+        help="If empty all warehouses are used.")
+
+    @classmethod
+    def default_warehouses(cls):
+        pool = Pool()
+        Location = pool.get('stock.location')
+        warehouse = Location.get_default_warehouse()
+        if warehouse:
+            return [warehouse]
